BTCAddress class
Address like BitCoin
data format: "network+digest+code"
network -- 1 byte
digest -- 20 bytes
check code -- 4 bytes
algorithm:
fingerprint = PK.data
digest = ripemd160(sha256(fingerprint));
code = sha256(sha256(network + digest)).prefix(4);
address = base58_encode(network + digest + code);
- Inheritance
-
- Object
- ConstantString
- BTCAddress
- Implemented types
Constructors
- BTCAddress(Object string, int network)
Properties
-
codeUnits
→ List<
int> -
An unmodifiable list of the UTF-16 code units of this string.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether this string is empty.
no setterinherited
- isNotEmpty → bool
-
Whether this string is not empty.
no setterinherited
- length → int
-
The length of the string.
no setterinherited
- network → int
-
Network identifier (type) of this address.
no setteroverride
- runes → Runes
-
An Iterable of Unicode code-points of this string.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allMatches(
String string, [int start = 0]) → Iterable< Match> -
Matches this pattern against the string repeatedly.
inherited
-
codeUnitAt(
int index) → int -
Returns the 16-bit UTF-16 code unit at the given
index.inherited -
compareTo(
String other) → int -
Compares this object to another object.
inherited
-
contains(
Pattern other, [int startIndex = 0]) → bool -
Whether this string contains a match of
other.inherited -
endsWith(
String other) → bool -
Whether this string ends with
other.inherited -
indexOf(
Pattern pattern, [int start = 0]) → int -
Returns the position of the first match of
patternin this string, starting atstart, inclusive:inherited -
lastIndexOf(
Pattern pattern, [int? start]) → int -
The starting position of the last match
patternin this string.inherited -
matchAsPrefix(
String string, [int start = 0]) → Match? -
Matches this pattern against the start of
string.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
padLeft(
int width, [String padding = ' ']) → String -
Pads this string on the left if it is shorter than
width.inherited -
padRight(
int width, [String padding = ' ']) → String -
Pads this string on the right if it is shorter than
width.inherited -
replaceAll(
Pattern from, String replace) → String -
Replaces all substrings that match
fromwithreplace.inherited -
replaceAllMapped(
Pattern from, String replace(Match match)) → String -
Replace all substrings that match
fromby a computed string.inherited -
replaceFirst(
Pattern from, String to, [int startIndex = 0]) → String -
Creates a new string with the first occurrence of
fromreplaced byto.inherited -
replaceFirstMapped(
Pattern from, String replace(Match match), [int startIndex = 0]) → String -
Replace the first occurrence of
fromin this string.inherited -
replaceRange(
int start, int? end, String replacement) → String -
Replaces the substring from
starttoendwithreplacement.inherited -
split(
Pattern pattern) → List< String> -
Splits the string at matches of
patternand returns a list of substrings.inherited -
splitMapJoin(
Pattern pattern, {String onMatch(Match)?, String onNonMatch(String)?}) → String -
Splits the string, converts its parts, and combines them into a new
string.
inherited
-
startsWith(
Pattern pattern, [int index = 0]) → bool -
Whether this string starts with a match of
pattern.inherited -
substring(
int start, [int? end]) → String -
The substring of this string from
start, inclusive, toend, exclusive.inherited -
toLowerCase(
) → String -
Converts all characters in this string to lower case.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toUpperCase(
) → String -
Converts all characters in this string to upper case.
inherited
-
trim(
) → String -
The string without any leading and trailing whitespace.
inherited
-
trimLeft(
) → String -
The string without any leading whitespace.
inherited
-
trimRight(
) → String -
The string without any trailing whitespace.
inherited
Operators
-
operator *(
int times) → String -
Creates a new string by concatenating this string with itself a number
of times.
inherited
-
operator +(
String other) → String -
Creates a new string by concatenating this string with
other.inherited -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → String -
The character (as a single-code-unit String) at the given
index.inherited
Static Methods
-
generate(
Uint8List fingerprint, int network) → BTCAddress -
Generate BTC address with fingerprint and network ID
override
-
parse(
String address) → BTCAddress? -
Parse a string for BTC address
override