runes property

  1. @override
Runes get runes
override

An Iterable of Unicode code-points of this string.

If the string contains surrogate pairs, they are combined and returned as one integer by this iterator. Unmatched surrogate halves are treated like valid 16-bit code-units.

Implementation

@override
Runes get runes => _str.runes;