Dictionary class

Implemented types
Implementers

Constructors

Dictionary([Map? dict])

Properties

entries Iterable<MapEntry<String, dynamic>>
The map entries of this Map.
no setteroverride
hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
Whether there is no key/value pair in the map.
no setteroverride
isNotEmpty bool
Whether there is at least one key/value pair in the map.
no setteroverride
keys Iterable<String>
The keys of this Map.
no setteroverride
length int
The number of key/value pairs in the map.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Iterable
The values of this Map.
no setteroverride

Methods

addAll(Map other) → void
Adds all key/value pairs of other to this map.
override
addEntries(Iterable<MapEntry<String, dynamic>> newEntries) → void
Adds all key/value pairs of newEntries to this map.
override
cast<RK, RV>() Map<RK, RV>
Map<String, dynamic>
override
clear() → void
Removes all entries from the map.
override
containsKey(Object? key) bool
Whether this map contains the given key.
override
containsValue(dynamic value) bool
Whether this map contains the given value.
override
copyMap([bool deepCopy = false]) Map
Creates a copy of the internal map.
override
forEach(void action(String key, dynamic value)) → void
Applies action to each key/value pair of the map.
override
getBool(String key, [bool? defaultValue]) bool?
override
getDateTime(String key, [DateTime? defaultValue]) DateTime?
override
getDouble(String key, [double? defaultValue]) double?
override
getInt(String key, [int? defaultValue]) int?
override
getString(String key, [String? defaultValue]) String?
Gets a string value for the given key.
override
map<K2, V2>(MapEntry<K2, V2> convert(String key, dynamic value)) Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(String key, dynamic ifAbsent()) → dynamic
Look up the value of key, or add a new entry if it isn't there.
override
remove(Object? key) → dynamic
Removes key and its associated value, if present, from the map.
override
removeWhere(bool test(String key, dynamic value)) → void
Removes all entries of this map that satisfy the given test.
override
setDateTime(String key, DateTime? time) → void
override
setMap(String key, Mapper? mapper) → void
override
setString(String key, Stringer? stringer) → void
override
toMap() Map
Returns the internal map as a Map.
override
toString() String
A string representation of this object.
override
update(String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
override
updateAll(dynamic update(String key, dynamic value)) → void
Updates all values.
override

Operators

operator ==(Object other) bool
The equality operator.
override
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
override
operator []=(String key, dynamic value) → void
Associates the key with the given value.
override