ECCKeyUtils class

Constructors

ECCKeyUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decodePrivateKey(String pem) → ECPrivateKey
Decode ECC private key from PEM text
decodePublicKey(String pem) → ECPublicKey
Decode ECC public key from PEM text
encodeKey({ECPublicKey? publicKey, ECPrivateKey? privateKey}) String
Encode Public/Private key to PEM Format
encodePrivateKeyData(ECPrivateKey privateKey) Uint8List
Encode ECC private key
encodePublicKeyData(ECPublicKey publicKey, {bool compressed = true}) Uint8List
Encode ECC public key
generatePrivateKey({String curve = 'secp256k1'}) → ECPrivateKey
Generate ECC private key
getSecureRandom({String name = 'Fortuna', int length = 32}) → SecureRandom
publicKeyFromPrivateKey(ECPrivateKey privateKey) → ECPublicKey
Calculate ECC public key from private key
sign(Uint8List data, ECPrivateKey privateKey) Uint8List
verify(Uint8List data, Uint8List signature, ECPublicKey publicKey) bool