SymmetricKeyFactory class abstract interface

Factory interface for creating and parsing SymmetricKey instances.

Provides methods to generate new symmetric keys and reconstruct them from serialized data.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateSymmetricKey() SymmetricKey
Generates a new random SymmetricKey using the default algorithm (typically AES).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseSymmetricKey(Map key) SymmetricKey?
Parses a serialized Map into a SymmetricKey instance.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited