crypto library
Cryptography
1. Crypto Keys
2. Data Digest
3. Data Format
Classes
- AESKey
- AES Key
- AESKeyFactory
- Arrays
- AsymmetricAlgorithms
- Algorithms for Asymmetric Key
- AsymmetricKey
- Base interface for asymmetric cryptographic keys (public/private key pairs).
- Base58
- Base58Coder
- Base-58
- Base64
- Base64Coder
- Base-64
- Base64Data
- Base-64 encoding
- BaseAsymmetricKey
- Asymmetric Keys
- BaseComparator
- BaseConverter
- BaseCopier
- BaseData
- BaseKey
- Base Keys
- BaseNetworkDataFactory
- BaseNetworkFileFactory
- BasePrivateKey
- BasePublicKey
- BaseString
- BaseSymmetricKey
- Symmetric Key
- BaseWrapper
- CharSequence
- Comparator
- Data Compare Interface
- ConstantString
- Converter
- Data Convert Interface
- Copier
- Data Copy Interface
- CryptographyKey
- Base interface for cryptographic keys with algorithm identification.
- DataCoder
- Interface for encoding/decoding binary data to/from string representations.
- DataComparator
- DataConverter
- DataCopier
- DataWrapper
- DecryptKey
- Interface for decryption keys (symmetric or asymmetric private keys).
- Dictionary
- ECCKeyUtils
- ECCPrivateKey
- ECC Private Key
- ECCPrivateKeyFactory
- ECCPublicKey
- ECC Public Key
- ECCPublicKeyFactory
- EmbedData
- RFC 2397
- EncodeAlgorithms
- Algorithms for Encoding Data
- EncryptKey
- Interface for encryption keys (symmetric or asymmetric public keys).
- Hex
- HexCoder
- Hex
- JSON
- JSONCoder
- JsON
- JSONMap
- KECCAK256
- KECCAK256Digester
- MapCoder
- coder for json <=> map
- Mapper
- MessageDigester
- Interface for computing cryptographic hashes (message digests) of binary data.
-
ObjectCoder<
T> - Generic interface for serializing/deserializing objects to/from string formats.
- PlainData
- UTF-8 encoding
- PlainKey
- Symmetric key for broadcast message, which will do nothing when en/decoding message data
- PlainKeyFactory
- PortableNetworkFile
- PortableNetworkFileWrapper
- PrivateKey
- Interface for asymmetric private keys (part of a key pair).
- PrivateKeyFactory
- Factory interface for creating and parsing PrivateKey instances.
- PublicKey
- Interface for asymmetric public keys (part of a key pair).
- PublicKeyFactory
- Factory interface for parsing PublicKey instances from serialized data.
- RIPEMD160
- RIPEMD160Digester
- RSAKeyUtils
- RSAPrivateKey
- RSA Private Key
- RSAPrivateKeyFactory
- RSAPublicKey
- RSA Public Key
- RSAPublicKeyFactory
- SHA256
- SHA256Digester
- SignKey
- Interface for private signing keys (asymmetric).
- StringCoder
- Interface for encoding/decoding strings to/from binary data (byte arrays).
- Stringer
- SymmetricAlgorithms
- Algorithms for Symmetric Key
- SymmetricKey
- Interface for symmetric cryptographic keys (single key for encryption/decryption).
- SymmetricKeyFactory
- Factory interface for creating and parsing SymmetricKey instances.
- TransportableData
- Transportable Encoded Data (TED) - encoded binary data for transport.
- TransportableDataFactory
- Factory interface for creating TransportableData (TED) instances.
- TransportableFile
- Portable Network File (PNF) - transportable file with metadata and encryption support.
- TransportableFileFactory
- Factory interface for creating TransportableFile (PNF) instances.
- TransportableFileWrapper
- A wrapper interface for serializing/deserializing TransportableFile data to/from a Map.
- TransportableFileWrapperFactory
- Factory interface for creating TransportableFileWrapper instances.
- TransportableResource
- Interface for serializable data or file content that supports multiple transport formats.
- UTF8
- UTF8Coder
- UTF-8
- VerifyKey
- Interface for public verification keys (asymmetric).
- Wrapper
- Data Wrap Interface