Generic interface for serializing/deserializing objects to/from string formats.
Supported serialization formats include (but are not limited to):
- JSON
- XML
Core functionality:
- Encode a structured object (typically Map or List) to a string
- Decode a string back to the original structured object
T: Type of the object to encode/decode (usually Map, List or custom model)
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(
String string) → T? - Decodes a serialized string back to a structured object.
-
encode(
T object) → String - Encodes a structured object to a serialized string.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited