Factory interface for creating and parsing PrivateKey instances.
Provides methods to generate new key pairs (private + public) and reconstruct private keys from serialized data.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generatePrivateKey(
) → PrivateKey - Generates a new asymmetric key pair and returns the PrivateKey.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parsePrivateKey(
Map key) → PrivateKey? - Parses a serialized Map into a PrivateKey instance.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited